==> tgp_2.0-1.tar.gz: tgp/man/tgp.default.params.Rd <==
\name{tgp.default.params}
\alias{tgp.default.params}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Default Treed Gaussian Process Model Parameters }
\description{
  Construct a default list of parameters to the \code{b*} 
  functions-- the interfaces to treed Gaussian process
  modeling
}
\usage{
tgp.default.params(d, meanfn = c("linear", "constant"),
                   corr = "expsep", ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{d}{ number of input dimensions \code{ncol(X)}}
  \item{meanfn}{ A choice of mean function for the process.  When
    \code{meanfn = "linear"} (default), then we have the process
    \deqn{Z = (\mathbf{1}  \;\; \mathbf{X}) \mbox{\boldmath $\beta$} + W(\mathbf{X})}{
      Z = cbind(rep(1,nrow(X), X)) \%*\% beta + W(X),}
  where \eqn{W(\mathbf{X})}{W(X)} represents the Gaussian process
  part of the model (if present).  Otherwise, when
  \code{meanfn = "constant"}, then\deqn{Z = \beta_0 + W(\mathbf{X})}{
    Z = beta0 + W(X).}}
  \item{corr}{ Gaussian process correlation model. Choose between the isotropic
  	power exponential family (\code{"exp"}) or the separable power exponential 
	family (\code{"expsep"}, default); the current version also supports 
	the isotropic Matern (\code{"matern"}) as \dQuote{beta}
	functionality.  The option \code{"mrexpsep"} uses a
	multi-resolution GP model.}
  \item{...}{ These ellipses arguments are interpreted as augmentations
    to the prior specification. You may use these to specify
    a custom setting of any of default parameters in the output list 
    detailed below}
}

\value{
   The output is the following list of \code{params}...

   \item{tree}{\code{c(0.5,2,max(c(10,col+1)),1)} indicating the tree prior
     parameters \eqn{\alpha}{alpha}, \eqn{\beta}{beta}, \emph{minpart}
     and \emph{splitmin}}
   \item{col}{dimension of regression coefficients \eqn{\mbox{\boldmath
	 $\beta$}}{beta}: 1 for input \code{meanfn = "constant"}, or
     \code{ncol(X)+1} for \code{meanfn = "linear"}}
   \item{meanfn}{ copied from the inputs }
   \item{corr}{ copied from the inputs }
   \item{bprior}{Linear (beta) prior, default is \code{"bflat"}
     which gives an \dQuote{improper} prior which can perform badly 
     when the signal-to-noise ratio is low.  In these cases the 
     \dQuote{proper} hierarchical specification \code{"b0"} or
     \code{"bmzt"} prior may perform better
     }
   \item{start}{\code{c(0.5,0.1,1.0,1.0)} starting values for range \eqn{d}{d},
     nugget \eqn{g}{g}, \eqn{\sigma^2}{s2}, and \eqn{\tau^2}{tau2}}
   \item{beta}{\code{rep(0,col)} starting values for beta linear parameters}
   \item{tree}{\code{c(0.25,2,min(c(10,col+1)))} tree prior process parameters 
     \code{c(alpha, beta, nmin)} specifying
     \deqn{p_{\mbox{\tiny split}}(\eta, \mathcal{T}) =
	  \alpha*(1+\eta)^\beta}{p(split leaf eta) = alpha*(1+depth(eta))^(-beta)}
	with zero probability given to trees
	with partitions containing less than \code{nmin} data points}
      \item{s2.p}{\code{c(5,10)} \eqn{\sigma^2}{s2} inverse-gamma prior
	parameters \code{c(a0, g0)} where \code{g0} is scale (1/rate) parameter}
      \item{tau2.p}{\code{c(5,10)} \eqn{\tau^2}{tau2} inverse-gamma
	prior parameters \code{c(a0, g0)} where \code{g0} is scale (1/rate) parameter}
   \item{d.p}{c(1.0,20.0,10.0,10.0) Mixture of gamma prior parameter (initial values)
     for the range parameter(s) \code{c(a1,g1,a2,g2)} where \code{g1} and
     \code{g2} are scale (1/rate) parameters.  If
     \code{corr="mrexpsep"}, then this is a vector of length 8: The
     first four parameters remain the same and correspond to the
     "coarse" process, and the
     second set of four values, which default to \code{c(1,10,1,10)},
     are the equivalent prior parameters for the range parameter(s) in the residual "fine" process.}
   \item{nug.p}{\code{c(1,1,1,1)} Mixture of gamma prior parameter (initial values)
     for the nugget parameter \code{c(a1,g1,a2,g2)} where \code{g1} and
     \code{g2} are scale (1/rate) parameters; default reduces to simple exponential prior}
   \item{gamma}{\code{c(10,0.2,10)}
        LLM parameters c(g, t1, t2), with growth parameter \code{g > 0}
  	minimum parameter \code{t1 >= 0} and maximum parameter \code{t1 >= 0}, where
	\code{t1 + t2 <= 1} specifies \deqn{p(b|d)=t_1 +
	  \exp\left\{\frac{-g(t_2-t_1)}{d-0.5}\right\}}{p(b|d)= t1 +
	  exp(-g*(t2-t1)/(d-0.5))}}
      \item{d.lam}{\code{"fixed"} Hierarchical exponential distribution
	parameters to \code{a1}, \code{g1}, \code{a2}, and \code{g2}
	of the prior distribution for the range parameter \code{d.p};
	\code{"fixed"} indicates that the hierarchical prior is \dQuote{turned off}}
      \item{nug.lam}{\code{"fixed"} Hierarchical exponential
	distribution parameters to \code{a1}, \code{g1},
   	\code{a2}, and \code{g2} of the prior distribution for the nug
	parameter \code{nug.p}; \code{"fixed"} indicates that the
	hierarchical prior is \dQuote{turned off}}
   \item{s2.lam}{\code{c(0.2,10)} Hierarchical exponential distribution prior for 
     \code{a0} and \code{g0} of the prior distribution for the s2
     parameter \code{s2.p}; \code{"fixed"} indicates that the
     hierarchical prior is \dQuote{turned off}}
   \item{tau2.lam}{\code{c(0.2,0.1)} Hierarchical exponential distribution prior for 
     \code{a0} and \code{g0} of the prior distribution for the s2
     parameter \code{tau2.p}; \code{"fixed"} indicates that the
     hierarchical prior is \dQuote{turned off}}
   \item{delta.p}{\code{c(1,1,1,1)}  Parameters in the mixture of gammas prior
     on the delta scaling parameter for \code{corr="mrexpsep"}:
     \code{c(a1,g1,a2,g2)} where \code{g1} and
     \code{g2} are scale (1/rate) parameters; default reduces to simple
     exponential prior.  Delta scales the variance of the residual "fine" process with respect to
     the variance of the underlying "coarse" process. }
   \item{nugf.p}{\code{c(1,1,1,1)}  Parameters in the mixture of gammas prior
       on the residual "fine" process nugget parameter for
       \code{corr="mrexpsep"}: \code{c(a1,g1,a2,g2)} where \code{g1} and
     \code{g2} are scale (1/rate) parameters; default reduces to simple exponential prior. }
}


\references{
Gramacy, R. B. (2007). \emph{\pkg{tgp}: An \R Package for Bayesian Nonstationary, Semiparametric Nonlinear Regression and Design by Treed Gaussian Process Models.}
Journal of Statistical Software, \bold{19}(9).

\url{http://www.jstatsoft.org/v19/i09}
Gramacy, R. B., Lee, H. K. H. (2006).
\emph{Bayesian treed Gaussian process models.}
Available as UCSC Technical Report ams2006-01. 

\url{http://www.ams.ucsc.edu/~rbgramacy/tgp.html}
}

\author{ 
\item{}{Robert B. Gramacy, \email{rbgramacy@ams.ucsc.edu}}
\item{}{Matt Taddy, \email{taddy@ams.ucsc.edu} }
}

\note{Please refer to the examples for the functions in
"See Also" below and \code{vignette("tgp")}
}

\seealso{ \code{\link{blm}}, \code{\link{btlm}}, \code{\link{bgp}},
  \code{\link{btgp}}, \code{\link{bgpllm}}, \code{\link{btgpllm}} }

\keyword{ nonparametric }
\keyword{ smooth }
\keyword{ models }
\keyword{ spatial }
\keyword{ tree }

==> tgp_2.0-3.tar.gz: tgp/man/tgp.default.params.Rd <==
\name{tgp.default.params}
\alias{tgp.default.params}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Default Treed Gaussian Process Model Parameters }
\description{
  Construct a default list of parameters to the \code{b*} 
  functions-- the interfaces to treed Gaussian process
  modeling
}
\usage{
tgp.default.params(d, meanfn = c("linear", "constant"),
                   corr = "expsep", ...)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{d}{ number of input dimensions \code{ncol(X)}}
  \item{meanfn}{ A choice of mean function for the process.  When
    \code{meanfn = "linear"} (default), then we have the process
    \deqn{Z = (\mathbf{1}  \;\; \mathbf{X}) \mbox{\boldmath $\beta$} + W(\mathbf{X})}{
      Z = cbind(rep(1,nrow(X), X)) \%*\% beta + W(X),}
  where \eqn{W(\mathbf{X})}{W(X)} represents the Gaussian process
  part of the model (if present).  Otherwise, when
  \code{meanfn = "constant"}, then\deqn{Z = \beta_0 + W(\mathbf{X})}{
    Z = beta0 + W(X).}}
  \item{corr}{ Gaussian process correlation model. Choose between the isotropic
  	power exponential family (\code{"exp"}) or the separable power exponential 
	family (\code{"expsep"}, default); the current version also supports 
	the isotropic Matern (\code{"matern"}) as \dQuote{beta}
	functionality.  The option \code{"mrexpsep"} uses a
	multi-resolution GP model.}
  \item{...}{ These ellipses arguments are interpreted as augmentations
    to the prior specification. You may use these to specify
    a custom setting of any of default parameters in the output list 
    detailed below}
}

\value{
   The output is the following list of \code{params}...

   \item{col}{dimension of regression coefficients \eqn{\mbox{\boldmath
	 $\beta$}}{beta}: 1 for input \code{meanfn = "constant"}, or
     \code{ncol(X)+1} for \code{meanfn = "linear"}}
   \item{meanfn}{ copied from the inputs }
   \item{corr}{ copied from the inputs }
   \item{bprior}{Linear (beta) prior, default is \code{"bflat"}
     which gives an \dQuote{improper} prior which can perform badly 
     when the signal-to-noise ratio is low.  In these cases the 
     \dQuote{proper} hierarchical specification \code{"b0"} or
     \code{"bmzt"} prior may perform better
     }
   \item{start}{\code{c(0.5,0.1,1.0,1.0)} starting values for range \eqn{d}{d},
     nugget \eqn{g}{g}, \eqn{\sigma^2}{s2}, and \eqn{\tau^2}{tau2}}
   \item{beta}{\code{rep(0,col)} starting values for beta linear parameters}
   \item{tree}{\code{c(0.5,2,min(c(10,col+1)),1)} indicating the tree prior 
     process parameters \eqn{\alpha}{alpha}, \eqn{\beta}{beta}, \emph{minpart}
     and \emph{splitmin}:
     \deqn{p_{\mbox{\tiny split}}(\eta, \mathcal{T}) =
       \alpha*(1+\eta)^\beta}{p(split leaf eta) =
       alpha*(1+depth(eta))^(-beta)}
	with zero probability given to trees
	with partitions containing less than \code{nmin} data points;
        \emph{splitmin} indicates the first column of \code{X} which 
        where treed partitioning is allowed}
      \item{s2.p}{\code{c(5,10)} \eqn{\sigma^2}{s2} inverse-gamma prior
	parameters \code{c(a0, g0)} where \code{g0} is scale (1/rate) parameter}
      \item{tau2.p}{\code{c(5,10)} \eqn{\tau^2}{tau2} inverse-gamma
	prior parameters \code{c(a0, g0)} where \code{g0} is scale (1/rate) parameter}
   \item{d.p}{c(1.0,20.0,10.0,10.0) Mixture of gamma prior parameter (initial values)
     for the range parameter(s) \code{c(a1,g1,a2,g2)} where \code{g1} and
     \code{g2} are scale (1/rate) parameters.  If
     \code{corr="mrexpsep"}, then this is a vector of length 8: The
     first four parameters remain the same and correspond to the
     "coarse" process, and the
     second set of four values, which default to \code{c(1,10,1,10)},
     are the equivalent prior parameters for the range parameter(s) in the residual "fine" process.}
   \item{nug.p}{\code{c(1,1,1,1)} Mixture of gamma prior parameter (initial values)
     for the nugget parameter \code{c(a1,g1,a2,g2)} where \code{g1} and
     \code{g2} are scale (1/rate) parameters; default reduces to simple exponential prior}
   \item{gamma}{\code{c(10,0.2,10)}
        LLM parameters c(g, t1, t2), with growth parameter \code{g > 0}
  	minimum parameter \code{t1 >= 0} and maximum parameter \code{t1 >= 0}, where
	\code{t1 + t2 <= 1} specifies \deqn{p(b|d)=t_1 +
	  \exp\left\{\frac{-g(t_2-t_1)}{d-0.5}\right\}}{p(b|d)= t1 +
	  exp(-g*(t2-t1)/(d-0.5))}}
      \item{d.lam}{\code{"fixed"} Hierarchical exponential distribution
	parameters to \code{a1}, \code{g1}, \code{a2}, and \code{g2}
	of the prior distribution for the range parameter \code{d.p};
	\code{"fixed"} indicates that the hierarchical prior is \dQuote{turned off}}
      \item{nug.lam}{\code{"fixed"} Hierarchical exponential
	distribution parameters to \code{a1}, \code{g1},
   	\code{a2}, and \code{g2} of the prior distribution for the nug
	parameter \code{nug.p}; \code{"fixed"} indicates that the
	hierarchical prior is \dQuote{turned off}}
   \item{s2.lam}{\code{c(0.2,10)} Hierarchical exponential distribution prior for 
     \code{a0} and \code{g0} of the prior distribution for the s2
     parameter \code{s2.p}; \code{"fixed"} indicates that the
     hierarchical prior is \dQuote{turned off}}
   \item{tau2.lam}{\code{c(0.2,0.1)} Hierarchical exponential distribution prior for 
     \code{a0} and \code{g0} of the prior distribution for the s2
     parameter \code{tau2.p}; \code{"fixed"} indicates that the
     hierarchical prior is \dQuote{turned off}}
   \item{delta.p}{\code{c(1,1,1,1)}  Parameters in the mixture of gammas prior
     on the delta scaling parameter for \code{corr="mrexpsep"}:
     \code{c(a1,g1,a2,g2)} where \code{g1} and
     \code{g2} are scale (1/rate) parameters; default reduces to simple
     exponential prior.  Delta scales the variance of the residual "fine" process with respect to
     the variance of the underlying "coarse" process. }
   \item{nugf.p}{\code{c(1,1,1,1)}  Parameters in the mixture of gammas prior
       on the residual \dQuote{fine} process nugget parameter for
       \code{corr="mrexpsep"}: \code{c(a1,g1,a2,g2)} where \code{g1} and
     \code{g2} are scale (1/rate) parameters; default reduces to simple exponential prior.
   }
}


\references{
Gramacy, R. B. (2007). \emph{\pkg{tgp}: An \R Package for Bayesian Nonstationary, Semiparametric Nonlinear Regression and Design by Treed Gaussian Process Models.}
Journal of Statistical Software, \bold{19}(9).

\url{http://www.jstatsoft.org/v19/i09}
Gramacy, R. B., Lee, H. K. H. (2006).
\emph{Bayesian treed Gaussian process models.}
Available as UCSC Technical Report ams2006-01. 

\url{http://www.ams.ucsc.edu/~rbgramacy/tgp.html}
}

\author{ 
\item{}{Robert B. Gramacy, \email{rbgramacy@ams.ucsc.edu}}
\item{}{Matt Taddy, \email{taddy@ams.ucsc.edu} }
}

\note{Please refer to the examples for the functions in
"See Also" below and \code{vignette("tgp")}
}

\seealso{ \code{\link{blm}}, \code{\link{btlm}}, \code{\link{bgp}},
  \code{\link{btgp}}, \code{\link{bgpllm}}, \code{\link{btgpllm}} }

\keyword{ nonparametric }
\keyword{ smooth }
\keyword{ models }
\keyword{ spatial }
\keyword{ tree }
